==> lxqt-notificationd_1.3.0.orig.tar.xz: lxqt-notificationd-1.3.0/config/translations/lxqt-config-notificationd_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> 픽셀</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>간격:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>지속시간</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>일부 알림은 자체 화면 지속시간을 설정합니다.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>기본 지속시간:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation>화면</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>선택하지 않으면 알림이 항상 기본 화면에 표시됩니다</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>마우스로 화면에 알림 표시</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="196"/>
        <source>Do Not Disturb</source>
        <translation>방해하지 않음</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="202"/>
        <source>Only save notifications</source>
        <translation>알림만 저장</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>확인되지 않은 알림</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>저장할 수 있는 횟수:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>응용프로그램 이름은 알림 상단에 있습니다.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>다음 응용프로그램 무시:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>앱1,앱2,앱3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Position on screen</source>
        <translation>화면에서의 위치</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="176"/>
        <source>Preview</source>
        <translation>미리보기</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="63"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 알림 데몬의 응답 속도가 느립니다.
계속 연결을 시도하십시오…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="72"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 실행 중인 알림 데몬이 없습니다.
대체가 사용됩니다.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="75"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 타사 알림 데몬(%1)이 실행 중입니다.
이 설정은 아무런 영향을 미치지 않습니다!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>at top left</source>
        <translation>왼쪽 상단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="139"/>
        <source>at top center</source>
        <translation>상단 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="141"/>
        <source>at top right</source>
        <translation>오른쪽 상단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="143"/>
        <source>at center left</source>
        <translation>왼쪽 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="145"/>
        <source>at center right</source>
        <translation>오른쪽 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="147"/>
        <source>at bottom left</source>
        <translation>왼쪽 하단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="149"/>
        <source>at bottom center</source>
        <translation>하단 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="151"/>
        <source>at bottom right</source>
        <translation>오른쪽 하단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="153"/>
        <source>Notification demo </source>
        <translation>알림 데모 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>이것은 테스트 알림입니다.
 이제 모든 알림이 LXQt에 표시됩니다.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>바탕화면 알림</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>일반 설정</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Position</source>
        <translation>위치</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_1.4.0.orig.tar.xz: lxqt-notificationd-1.4.0/config/translations/lxqt-config-notificationd_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>지속시간</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>일부 알림은 자체 화면 지속시간을 설정합니다.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>기본 지속시간:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>화면</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>선택하지 않으면 알림이 항상 기본 화면에 표시됩니다</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>마우스로 화면에 알림 표시</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>방해하지 않음</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>알림만 저장</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>확인되지 않은 알림</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>저장할 수 있는 횟수:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>응용프로그램 이름은 알림 상단에 있습니다.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>다음 응용프로그램 무시:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>앱1,앱2,앱3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> 픽셀</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>간격:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>화면에서의 위치</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>미리보기</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 알림 데몬의 응답 속도가 느립니다.
계속 연결을 시도하십시오…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 실행 중인 알림 데몬이 없습니다.
대체가 사용됩니다.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;경고:&lt;/b&gt; 타사 알림 데몬(%1)이 실행 중입니다.
이 설정은 아무런 영향을 미치지 않습니다!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>왼쪽 상단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>상단 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>오른쪽 상단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>왼쪽 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>오른쪽 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>왼쪽 하단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>하단 중앙에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>오른쪽 하단에</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>알림 데모 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>이것은 테스트 알림입니다.
 이제 모든 알림이 LXQt에 표시됩니다.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>바탕화면 알림</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>일반 설정</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>모양새</translation>
    </message>
</context>
</TS>
